##  Setting Fields as Read-Only
To prevent users from updating a field, you can set it as read-only. To do this, on the right-side panel, navigate to the Options tab indicated by a gear icon, turn on the Is read-only toggle, then save the changes.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a27737a44101493c8d2d44763002b_LowRes.png)
**Note**
When you set fields as read-only in the meta model configuration, users cannot update these fields in the application UI. However, users with appropriate permissions can update read-only fields using the API.
Setting fields as read-only isn't a security or permission feature.
